@@ -77,9 +77,10 @@ class Bookmarks:
         # those spots.  These spots are known as 'bookmarks'. 
         #
         utterances = [_('bookmark entered')]
-        utterances.extend(self._script.speechGenerator.getSpeech( \
-                          context.getCurrentAccessible(), False))
-        speech.speakUtterances(utterances)
+        utterances.extend(
+            self._script.speechGenerator.generateSpeech(
+                context.getCurrentAccessible()))
+        speech.speak(utterances)
 
     def bookmarkCurrentWhereAmI(self, inputEvent):
         """ Report "Where am I" information for this bookmark relative to the 
@@ -95,18 +96,19 @@ class Bookmarks:
         cur_obj = orca_state.locusOfFocus
 
         # Are they the same object?
-        if self._script.isSameObject(cur_obj, obj):
+        if self._script.utilities.isSameObject(cur_obj, obj):
             # Translators: this announces that the current object is the same
             # object pointed to by the bookmark.
             #
-            speech.speak(_('bookmark is current object'))
+            self._script.presentMessage(_('bookmark is current object'))
             return
         # Are their parents the same?
-        elif self._script.isSameObject(cur_obj.parent, obj.parent):
+        elif self._script.utilities.isSameObject(cur_obj.parent, obj.parent):
             # Translators: this announces that the current object's parent and 
             # the parent of the object pointed to by the bookmark are the same.
             #
-            speech.speak(_('bookmark and current object have same parent'))
+            self._script.presentMessage(
+                _('bookmark and current object have same parent'))
             return
 
         # Do they share a common ancestor?
@@ -123,14 +125,14 @@ class Bookmarks:
                 # Translators: this announces that the bookmark and the current
                 # object share a common ancestor
                 #
-                speech.speak(_('shared ancestor %s') %p.role)
+                self._script.presentMessage(_('shared ancestor %s') % p.role)
                 return
             p = p.parent
 
         # Translators: This announces that a comparison between the bookmark
         # and the current object can not be determined.
         #
-        speech.speak(_('comparison unknown'))
+        self._script.presentMessage(_('comparison unknown'))
 
     def saveBookmarks(self, inputEvent):
         """ Save the bookmarks for this script. """        
@@ -139,12 +141,12 @@ class Bookmarks:
             # Translators: this announces that a bookmark has been saved to 
             # disk
             #
-            speech.speak(_('bookmarks saved'))
+            self._script.presentMessage(_('bookmarks saved'))
         except IOError:
             # Translators: this announces that a bookmark could not be saved to 
             # disk
             #
-            speech.speak(_('bookmarks could not be saved'))
+            self._script.presentMessage(_('bookmarks could not be saved'))
 
         # Notify the observers
         for o in self._saveObservers:
