@@ -60,9 +60,8 @@ class GeckoBookmarks(bookmarks.Bookmarks):
         # Translators: this announces that a bookmark has been entered
         #
         utterances = [(_('entered bookmark'))]
-        utterances.extend(self._script.speechGenerator.getSpeech \
-                         (obj, False))
-        speech.speakUtterances(utterances)
+        utterances.extend(self._script.speechGenerator.generateSpeech(obj))
+        speech.speak(utterances)
         
     def goToBookmark(self, inputEvent, index=None):
         """ Go to the bookmark indexed at this key and this page's URI """
@@ -101,18 +100,19 @@ class GeckoBookmarks(bookmarks.Bookmarks):
         [cur_obj, cur_characterOffset] = self._script.getCaretContext()
         
         # Are they the same object?
-        if self._script.isSameObject(cur_obj, obj):
+        if self._script.utilities.isSameObject(cur_obj, obj):
             # Translators: this announces that the current object is the same
             # object pointed to by the bookmark.
             #
-            speech.speak(_('bookmark is current object'))
+            self._script.presentMessage(_('bookmark is current object'))
             return
         # Are their parents the same?
-        elif self._script.isSameObject(cur_obj.parent, obj.parent):
+        elif self._script.utilities.isSameObject(cur_obj.parent, obj.parent):
             # Translators: this announces that the current object's parent and 
             # the parent of the object pointed to by the bookmark are the same.
             #
-            speech.speak(_('bookmark and current object have same parent'))
+            self._script.presentMessage(
+                _('bookmark and current object have same parent'))
             return
         
         # Do they share a common ancestor?
@@ -129,14 +129,15 @@ class GeckoBookmarks(bookmarks.Bookmarks):
                 # Translators: this announces that the bookmark and the current
                 # object share a common ancestor
                 #
-                speech.speak(_('shared ancestor %s') %p.getRole())
+                self._script.presentMessage(
+                    _('shared ancestor %s') % p.getRole())
                 return
             p = p.parent
         
         # Translators: This announces that a comparison between the bookmark
         # and the current object can not be determined.
         #
-        speech.speak(_('comparison unknown'))
+        self._script.presentMessage(_('comparison unknown'))
         
     def saveBookmarks(self, inputEvent):
         """ Save the bookmarks for this script. """
@@ -151,12 +152,12 @@ class GeckoBookmarks(bookmarks.Bookmarks):
             # Translators: this announces that a bookmark has been saved to 
             # disk
             #
-            speech.speak(_('bookmarks saved'))
+            self._script.presentMessage(_('bookmarks saved'))
         except IOError:
             # Translators: this announces that a bookmark could not be saved to 
             # disk
             #
-            speech.speak(_('bookmarks could not be saved'))
+            self._script.presentMessage(_('bookmarks could not be saved'))
 
         # Notify the observers
         for o in self._saveObservers:
@@ -272,7 +273,7 @@ class GeckoBookmarks(bookmarks.Bookmarks):
     def pathToObj(self, path):
         """Return the object with the given path (relative to the
         document frame). """
-        returnobj = self._script.getDocumentFrame()
+        returnobj = self._script.utilities.documentFrame()
         for childnumber in path:
             try:
                 returnobj = returnobj[childnumber]
@@ -284,7 +285,7 @@ class GeckoBookmarks(bookmarks.Bookmarks):
     def getURIKey(self):
         """Returns the URI key for a given page as a URI stripped of 
         parameters?query#fragment as seen in urlparse."""
-        uri = self._script.getDocumentFrameURI()
+        uri = self._script.utilities.documentFrameURI()
         if uri:
             parsed_uri = urlparse.urlparse(uri)
             return ''.join(parsed_uri[0:3])
