@@ -89,6 +89,7 @@ from orca_i18n import C_          # to provide qualified translatable strings
 userCustomizableSettings = [
     "orcaModifierKeys",
     "enableSpeech",
+    "onlySpeakDisplayedText",
     "speechServerFactory",
     "speechServerInfo",
     "voices",
@@ -364,6 +365,11 @@ enableSpeechCallbacks   = True
 #
 silenceSpeech           = False
 
+# If True, only text which is displayed on screen will be spoken
+# (roles, states, etc. will not be).
+#
+onlySpeakDisplayedText = False
+
 # Settings that apply to the particular speech engine to
 # use as well details on the default voices to use.
 #
@@ -857,15 +863,9 @@ listShortcutsModeEnabled = False
 # The location of the user's preferences. By default this is
 # $XDG_DATA_HOME/orca.
 # It can be overridden by the Orca -d command line option.
-# For migration reasons the old location (~/.orca) will be
-# checking. If this path exists it will be the location.
 #
-userPrefsDir = os.path.join(os.environ["HOME"], ".orca")
-
-if not os.path.exists(userPrefsDir):
-    from xdg.BaseDirectory import xdg_data_home
-
-    userPrefsDir = os.path.join(xdg_data_home, "orca")
+from xdg.BaseDirectory import xdg_data_home
+userPrefsDir = os.path.join(xdg_data_home, "orca")
 
 # Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
 # always mean an object disappeared - there just might be a network
