@@ -39,11 +39,15 @@ __copyright__ = "Copyright (c) 2006-2008 Brailcom, o.p.s."
 __license__   = "LGPL"
 
 import gobject
+import re
 
+import chnames
 import debug
 import speechserver
 import settings
 import orca
+import orca_state
+import punctuation_settings
 from acss import ACSS
 from orca_i18n import _
 
@@ -60,6 +64,9 @@ else:
     else:
         _speechd_version_ok = True
 
+PUNCTUATION = re.compile('[^\w\s]', re.UNICODE)
+ELLIPSIS = re.compile('(\342\200\246|\.\.\.\s*)')
+
 class SpeechServer(speechserver.SpeechServer):
     # See the parent class for documentation.
 
@@ -221,9 +228,12 @@ class SpeechServer(speechserver.SpeechServer):
         self._send_command(self._client.set_volume, volume)
 
     def _set_family(self, acss_family):
-        locale = acss_family[speechserver.VoiceFamily.LOCALE]
-        if locale:
-            lang = locale.split('_')[0]
+        familyLocale = acss_family.get(speechserver.VoiceFamily.LOCALE)
+        if not familyLocale:
+            import locale
+            familyLocale, encoding = locale.getdefaultlocale()
+        if familyLocale:
+            lang = familyLocale.split('_')[0]
             if lang and len(lang) == 2:
                 self._send_command(self._client.set_language, lang)
         try:
@@ -232,7 +242,7 @@ class SpeechServer(speechserver.SpeechServer):
         except AttributeError:
             pass
         else:
-            name = acss_family[speechserver.VoiceFamily.NAME]
+            name = acss_family.get(speechserver.VoiceFamily.NAME)
             if name != self._default_voice_name:
                 self._send_command(set_synthesis_voice, name)
             
@@ -242,11 +252,67 @@ class SpeechServer(speechserver.SpeechServer):
         current = self._current_voice_properties
         for acss_property, method in self._acss_manipulators:
             value = acss.get(acss_property)
-            if value is not None and current.get(acss_property) != value:
-                method(value)
-                current[acss_property] = value
+            if value is not None:
+                if current.get(acss_property) != value:
+                    method(value)
+                    current[acss_property] = value
+            elif acss_property == ACSS.FAMILY and current.get(acss_property) \
+                    and acss == settings.voices[settings.DEFAULT_VOICE]:
+                # We need to explicitly reset (at least) the family.
+                # See bgo#626072.
+                #
+                method({})
+                current[acss_property] = {}
+
+    def __addVerbalizedPunctuation(self, oldText):
+        """Depending upon the users verbalized punctuation setting,
+        adjust punctuation symbols in the given text to their pronounced
+        equivalents. The pronounced text will either replace the
+        punctuation symbol or be inserted before it. In the latter case,
+        this is to retain spoken prosity.
+
+        Arguments:
+        - oldText: text to be parsed for punctuation.
+
+        Returns a text string with the punctuation symbols adjusted accordingly.
+        """
+
+        # Translators: we replace the ellipses (both manual and UTF-8)
+        # with a spoken string.  The extra space you see at the beginning
+        # is because we need the speech synthesis engine to speak the
+        # new string well.  For example, "Open..." turns into
+        # "Open dot dot dot".
+        #
+        spokenEllipsis = _(" dot dot dot")
+        newText = re.sub(ELLIPSIS, spokenEllipsis, oldText)
+        newText = newText.decode("UTF-8")
+
+        symbols = set(re.findall(PUNCTUATION, newText))
+        for symbol in symbols:
+            try:
+                level, action = punctuation_settings.getPunctuationInfo(symbol)
+            except:
+                continue
+
+            if level != punctuation_settings.LEVEL_NONE:
+                # Speech Dispatcher should handle it.
+                #
+                continue
+
+            charName = " %s " % chnames.getCharacterName(symbol)
+            if action == punctuation_settings.PUNCTUATION_INSERT:
+                charName += symbol
+            newText = re.sub(symbol, charName, newText)
+
+        if orca_state.activeScript:
+            newText = orca_state.activeScript.utilities.adjustForDigits(newText)
+
+        return newText.encode("UTF-8")
 
     def _speak(self, text, acss, **kwargs):
+        if isinstance(text, ACSS):
+            text = ''
+        text = self.__addVerbalizedPunctuation(text)
         # Replace no break space characters with plain spaces since some
         # synthesizers cannot handle them.  See bug #591734.
         #
@@ -365,8 +431,17 @@ class SpeechServer(speechserver.SpeechServer):
         self._apply_acss(acss)
         if character == '\n':
             self._send_command(self._client.sound_icon, 'end-of-line')
-        else:
+            return
+
+        name = chnames.getCharacterName(character)
+        if not name:
             self._send_command(self._client.char, character)
+            return
+
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            name = orca_state.activeScript.\
+                utilities.adjustForPronunciation(name)
+        self.speak(name, acss)
 
     def speakKeyEvent(self, event_string, eventType):
         if eventType == orca.KeyEventType.PRINTABLE:
